@@ -1,6 +1,13 @@
-/* brlzon.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/* brlzon.f -- translated by f2c (version 20050501).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "f2c.h"
@@ -125,17 +132,17 @@ static integer c__500 = 500;
 /* ********************************************************************** */
     /* Parameter adjustments */
     fmat2d_dim1 = *n3;
-    fmat2d_offset = 1 + fmat2d_dim1 * 1;
+    fmat2d_offset = 1 + fmat2d_dim1;
     fmat2d -= fmat2d_offset;
     --fmatrx;
     b_dim1 = *mono3;
-    b_offset = 1 + b_dim1 * 1;
+    b_offset = 1 + b_dim1;
     b -= b_offset;
     vec_dim1 = *mono3;
-    vec_offset = 1 + vec_dim1 * 1;
+    vec_offset = 1 + vec_dim1;
     vec -= vec_offset;
     sec_dim1 = *mono3;
-    sec_offset = 1 + sec_dim1 * 1;
+    sec_offset = 1 + sec_dim1;
     sec -= sec_offset;
 
     /* Function Body */
