@@ -1,6 +1,13 @@
-/* cdiag.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/* cdiag.f -- translated by f2c (version 20050501).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "f2c.h"
@@ -151,10 +158,10 @@ L80:
     /* Parameter adjustments */
     q -= 3;
     b_dim1 = *ia;
-    b_offset = 1 + b_dim1 * 1;
+    b_offset = 1 + b_dim1;
     b -= b_offset;
     a_dim1 = *ia;
-    a_offset = 1 + a_dim1 * 1;
+    a_offset = 1 + a_dim1;
     a -= a_offset;
 
     /* Function Body */
@@ -200,10 +207,10 @@ L80:
     /* Parameter adjustments */
     --value;
     vec_dim1 = *n;
-    vec_offset = 1 + vec_dim1 * 1;
+    vec_offset = 1 + vec_dim1;
     vec -= vec_offset;
     a_dim1 = *n;
-    a_offset = 1 + a_dim1 * 1;
+    a_offset = 1 + a_dim1;
     a -= a_offset;
 
     /* Function Body */
@@ -763,7 +770,7 @@ L50:
     --alpha;
     --beta;
     a_dim1 = *ia;
-    a_offset = 1 + a_dim1 * 1;
+    a_offset = 1 + a_dim1;
     a -= a_offset;
     --q;
 
@@ -930,7 +937,7 @@ L90:
     /* Parameter adjustments */
     --val;
     vec_dim1 = *n;
-    vec_offset = 1 + vec_dim1 * 1;
+    vec_offset = 1 + vec_dim1;
     vec -= vec_offset;
 
     /* Function Body */
