@@ -1,6 +1,13 @@
-/* deri2.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/* deri2.f -- translated by f2c (version 20050501).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "f2c.h"
@@ -262,29 +269,29 @@ static integer c__8 = 8;
 /* *********************************************************************** */
     /* Parameter adjustments */
     work_dim1 = *norbs;
-    work_offset = 1 + work_dim1 * 1;
+    work_offset = 1 + work_dim1;
     work -= work_offset;
     --e;
     c_dim1 = *norbs;
-    c_offset = 1 + c_dim1 * 1;
+    c_offset = 1 + c_dim1;
     c__ -= c_offset;
     ab_dim1 = *minear;
-    ab_offset = 1 + ab_dim1 * 1;
+    ab_offset = 1 + ab_dim1;
     ab -= ab_offset;
     b_dim1 = *minear;
-    b_offset = 1 + b_dim1 * 1;
+    b_offset = 1 + b_dim1;
     b -= b_offset;
     f_dim1 = *minear;
-    f_offset = 1 + f_dim1 * 1;
+    f_offset = 1 + f_dim1;
     f -= f_offset;
     fci_dim1 = *ninear;
-    fci_offset = 1 + fci_dim1 * 1;
+    fci_offset = 1 + fci_dim1;
     fci -= fci_offset;
     fd_dim1 = *ninear;
-    fd_offset = 1 + fd_dim1 * 1;
+    fd_offset = 1 + fd_dim1;
     fd -= fd_offset;
     fb_dim1 = *nvar;
-    fb_offset = 1 + fb_dim1 * 1;
+    fb_offset = 1 + fb_dim1;
     fb -= fb_offset;
     --grad;
 
