@@ -1,6 +1,13 @@
-/* interp.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/* interp.f -- translated by f2c (version 20050501).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "f2c.h"
@@ -155,16 +162,16 @@ static doublereal c_b132 = -1.;
     --vecl;
     --h__;
     p_dim1 = *n;
-    p_offset = 1 + p_dim1 * 1;
+    p_offset = 1 + p_dim1;
     p -= p_offset;
     fock_dim1 = *n;
-    fock_offset = 1 + fock_dim1 * 1;
+    fock_offset = 1 + fock_dim1;
     fock -= fock_offset;
     vec_dim1 = *n;
-    vec_offset = 1 + vec_dim1 * 1;
+    vec_offset = 1 + vec_dim1;
     vec -= vec_offset;
     cp_dim1 = *n;
-    cp_offset = 1 + cp_dim1 * 1;
+    cp_offset = 1 + cp_dim1;
     cp -= cp_offset;
     --fp;
 
@@ -938,7 +945,7 @@ L110:
 /* DECK MOPAC */
     /* Parameter adjustments */
     u_dim1 = *ndim;
-    u_offset = 1 + u_dim1 * 1;
+    u_offset = 1 + u_dim1;
     u -= u_offset;
 
     /* Function Body */
@@ -1088,7 +1095,7 @@ L110:
 /* DECK MOPAC */
     /* Parameter adjustments */
     u_dim1 = *ndim;
-    u_offset = 1 + u_dim1 * 1;
+    u_offset = 1 + u_dim1;
     u -= u_offset;
 
     /* Function Body */
