@@ -1,6 +1,13 @@
-/* meci.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/* meci.f -- translated by f2c (version 20050501).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "f2c.h"
@@ -315,7 +322,7 @@ doublereal meci_(doublereal *eigs, doublereal *coeff)
 
     /* Parameter adjustments */
     coeff_dim1 = molkst_1.norbs;
-    coeff_offset = 1 + coeff_dim1 * 1;
+    coeff_offset = 1 + coeff_dim1;
     coeff -= coeff_offset;
     --eigs;
 
